==> revolver-server-2.0.3-20200316.171517-4-sources.jar: io/dropwizard/revolver/vertx/RouterRegistry.java <==
package io.dropwizard.revolver.vertx;

import io.dropwizard.revolver.http.config.RevolverHttpApiConfig.RequestMethod;
import io.dropwizard.revolver.resource.RevolverRequestResource;
import io.vertx.core.http.HttpMethod;
import io.vertx.ext.web.Router;
import io.vertx.ext.web.RoutingContext;
import javax.ws.rs.core.HttpHeaders;
import javax.ws.rs.core.UriInfo;
import lombok.Builder;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@Data

public class RouterRegistry {

    private final Router router;

    private final RevolverRequestResource revolverRequestResource;

    @Builder
    public RouterRegistry(Router router, RevolverRequestResource revolverRequestResource) {
        this.router = router;
        this.revolverRequestResource = revolverRequestResource;
    }

    public void register() {
        //Test APIs
        router.route()
                .path("/apis/*")
                .method(HttpMethod.GET)
                .handler(this::getResource);
        router.route()
                .path("/apis/*")
                .method(HttpMethod.POST)
                .handler(this::getResource);
    }

    private void getResource(RoutingContext routingContext) {
        UriInfo uriInfo = RequestUtil.getUriInfo(routingContext);
        HttpHeaders headers = RequestUtil.getHeaders(routingContext);
        String service = RequestUtil.getServiceName(routingContext);
        String path = RequestUtil.getApiPath(routingContext);
        byte[] body = RequestUtil.getBody(routingContext);

        try {
            revolverRequestResource.processRequest(routingContext, service, RequestMethod.GET, path, headers, uriInfo,
                    body);
        } catch (Exception e) {
            log.error("Error occurred while executing resource ", e);
        }
        log.info("Execution completed : " + routingContext.getBody());
    }

}

==> revolver-server-2.0.4-20200316.180224-8-sources.jar: io/dropwizard/revolver/vertx/RouterRegistry.java <==
package io.dropwizard.revolver.vertx;

import io.dropwizard.revolver.http.config.RevolverHttpApiConfig.RequestMethod;
import io.dropwizard.revolver.resource.RevolverRequestResource;
import io.vertx.core.http.HttpMethod;
import io.vertx.ext.web.Router;
import io.vertx.ext.web.RoutingContext;
import javax.ws.rs.core.HttpHeaders;
import javax.ws.rs.core.UriInfo;
import lombok.Builder;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@Data

public class RouterRegistry {

    private final Router router;

    private final RevolverRequestResource revolverRequestResource;

    @Builder
    public RouterRegistry(Router router, RevolverRequestResource revolverRequestResource) {
        this.router = router;
        this.revolverRequestResource = revolverRequestResource;
    }

    public void register() {
        //Test APIs
        router.route()
                .path("/apis/*")
                .method(HttpMethod.GET)
                .handler(this::getResource);
        router.route()
                .path("/apis/*")
                .method(HttpMethod.POST)
                .handler(this::getResource);
    }

    private void getResource(RoutingContext routingContext) {
        log.info("Executing via vertx for path : {}", routingContext.normalisedPath());
        UriInfo uriInfo = RequestUtil.getUriInfo(routingContext);
        HttpHeaders headers = RequestUtil.getHeaders(routingContext);
        String service = RequestUtil.getServiceName(routingContext);
        String path = RequestUtil.getApiPath(routingContext);
        byte[] body = RequestUtil.getBody(routingContext);
        log.info("Service : {}, Path : {}", service, path);

        try {
            revolverRequestResource.processRequest(routingContext, service, RequestMethod.GET, path, headers, uriInfo,
                    body);
        } catch (Exception e) {
            log.error("Error occurred while executing resource ", e);
        }
        log.info("Execution completed : " + routingContext.getBody());
    }

}
